<?php

namespace App\Http\Controllers;

use App\Models\Farm_crop;
use App\Models\farm;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class FarmController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $farms=farm::all();
        if (session('success_message')){
            Alert::toast(session('success_message'),'success')->autoClose(4000);
        }



        return view('farm.index',compact('farms'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('farm.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        farm::create(
            $request->all()
        );
        return redirect()->route('farm.index')->withSuccessMessage('farm record created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\farm  $farm
     * @return \Illuminate\Http\Response
     */
    public function show(farm $farm)
    {
        $farm = farm::findorfail($farm->id);

        return view('farm.show',compact('farm'));

        // dd(compact('farm'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\farm  $farm
     * @return \Illuminate\Http\Response
     */
    public function edit(farm $farm)
    {
        return view('farm.edit',compact('farm'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\farm  $farm
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, farm $farm)
    {
        $farm->update([
            'name'=> $request->input('name'),
            'description'=> $request->input('description'),
            'size'=> $request->input('size'),

            'location'=>$request->input('location')
        ]);
        return redirect()->route('farm.index')->withSuccessMessage('farm updated  successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\farm  $farm
     * @return \Illuminate\Http\Response
     */
    public function destroy(farm $farm)
    {
        if ($farm->children()->exists()){
        return redirect()->route('category.index')->withToastWarning('cannot delete existing parent farm');
        }
        else{
            $farm->delete();
            return redirect()->route('farm.index')->withSuccessMessage('farm record deleted successfully');
        }

    }

    public function getInfo($farm_crop_id)
    {
        // Fetch the necessary data based on $farm_crop_id
        // For example:
        $farmCrop = Farm_crop::where('id',$farm_crop_id)->first();
        $farmname = farm::where('id',$farmCrop->farm_id)->first();

        
        return response()->json($farmname->size);
    }

    public function getFarmData(Request $request){
        // dd( $request->farm_id);


        // $farmData = Farm_crop::where('farm_id',$request->farm_id)->select('*')->get();

        $farmData = DB::table('farm_crops')
        ->join('crops', 'farm_crops.crop_id', '=', 'crops.id')
        ->join('farms', 'farm_crops.farm_id', '=', 'farms.id')
        ->where('farm_crops.farm_id', $request->farm_id)
        ->select( 'farms.name as farmnae' ,'crops.name as cropname','farms.size as farmsize')
        ->selectRaw("DATE_FORMAT(crops.created_at, '%d%b%y') as datepalnted")

        ->get();


     
        return response()->json(['data' => $farmData]);

    }


    public function getActivitiesData(Request $request){
        // dd( $request->farm_id);


        // $farmData = Farm_crop::where('farm_id',$request->farm_id)->select('*')->get();

        $farmData = DB::table('farm_crops')
        ->join('crops', 'farm_crops.crop_id', '=', 'crops.id')
        ->join('farms', 'farm_crops.farm_id', '=', 'farms.id')
        ->join('farm_registers', 'farm_crops.id', '=', 'farm_registers.farm_crop_id')

        ->join('categories','farm_registers.category_id' , '=', 'categories.id'  )

        ->where('farm_crops.farm_id', $request->farm_id)
        ->select( 'farms.name as farmnae' ,'crops.name as cropname','categories.name as operations','farm_registers.total_cost as cost')
        ->selectRaw("DATE_FORMAT(farm_registers.created_at, '%d%b%y') as date")
       
        ->get();
// dd( $farmData);


        return response()->json(['data' => $farmData]);

    }


    
}
